package com.fzs.parking.modules.platform.api.services.impl;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONObject;
import com.fzs.beehive.context.internal.ContextHolder;
import com.fzs.beehive.util.ObjectId;
import com.fzs.beehive.util.PV;
import com.fzs.beehive.util.ResultPack;
import com.fzs.beehive.util.StringUtils;
import com.fzs.parking.file.enums.PlatformTypeEnum;
import com.fzs.parking.file.service.CommonFileService;
import com.fzs.parking.modules.platform.api.common.ParkingVariable;
import com.fzs.parking.modules.platform.api.entities.LicensePlateResp;
import com.fzs.parking.modules.platform.api.entities.ReleaseRecord;
import com.fzs.parking.modules.platform.api.services.MessageFromDeviceHandleService;
import com.fzs.parking.modules.platform.api.services.NetSDKLib;
import com.fzs.parking.modules.platform.api.services.ThirdUtilService;
import com.fzs.parking.modules.platform.api.utils.CameraUtil;
import com.fzs.parking.modules.platform.enums.impl.AisleDirectionEnum;
import com.fzs.parking.modules.platform.enums.impl.ReleaseRecordCrossTypeEnum;
import com.fzs.parking.modules.platform.enums.impl.ReleaseRecordForbidTypeEnum;
import com.fzs.parking.modules.platform.enums.impl.ReleaseRecordPassTypeEnum;
import com.fzs.parking.modules.platform.parking.dao.CameraRecordDAO;
import com.fzs.parking.modules.platform.parking.dao.ParkingEquipDAO;
import com.fzs.parking.modules.platform.parking.entities.CameraRecord;
import com.fzs.parking.modules.platform.parking.entities.ParkingEquip;
import com.fzs.parking.modules.platform.parking.services.BillingResultService;
import com.fzs.parking.modules.platform.parking.services.CameraParam;
import com.fzs.parking.modules.utils.HttpClientUtil;
import java.io.File;
import java.util.Date;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.concurrent.CompletableFuture;
import java.util.concurrent.FutureTask;
import java.util.concurrent.TimeUnit;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.scheduling.concurrent.ThreadPoolTaskExecutor;
import org.springframework.stereotype.Service;
import org.springframework.util.ObjectUtils;

@Service
/* loaded from: MessageFromDeviceHandleServicImpl.class */
public class MessageFromDeviceHandleServicImpl implements MessageFromDeviceHandleService {
    private static final Logger logger = LoggerFactory.getLogger(MessageFromDeviceHandleServicImpl.class);

    @Autowired
    private ThreadPoolTaskExecutor executor;

    @Autowired
    private CameraRecordDAO cameraRecordDAO;

    @Autowired
    private BillingResultService billingResultService;

    @Value("${cloud.http.base.url}")
    private String httpBaseUrl;

    @Value("${cloud.http.circuit.breaker.time}")
    private long cloudHttpCircuitBreakerTime;

    @Autowired
    private ParkingEquipDAO parkingEquipDAO;

    @Autowired
    private ThirdUtilService thirdUtilService;

    public void recognitionAfterHandle(String ip, String plateNumber, String strColor, String picPath, String picPathVehicleNo) {
        this.executor.execute(() -> {
            logger.info("{}，{}，开始大图又拍云上传", ip, plateNumber);
            try {
                CommonFileService commonFileService = (CommonFileService) ContextHolder.get().service(CommonFileService.class);
                String remotePathWithOutFileName = picPath.substring(0, picPath.lastIndexOf("/") + 1);
                String url = commonFileService.uploadFile(remotePathWithOutFileName.substring(1), new File(CameraUtil.CLASS_PATH + picPath), PlatformTypeEnum.PLATFORM_TYPE.QINIUYUN.getCode());
                logger.info("上传七云的路径：{}", url);
            } catch (Exception e) {
                logger.error(e.getMessage(), e);
            }
            logger.info("{}，{}，又拍云大图上传结束", ip, plateNumber);
        });
        this.executor.execute(() -> {
            logger.info("{}，{}，开始特写又拍云上传", ip, plateNumber);
            try {
                CommonFileService commonFileService = (CommonFileService) ContextHolder.get().service(CommonFileService.class);
                String remotePathWithOutFileName = picPathVehicleNo.substring(0, picPathVehicleNo.lastIndexOf("/") + 1);
                String url = commonFileService.uploadFile(remotePathWithOutFileName.substring(1), new File(CameraUtil.CLASS_PATH + picPathVehicleNo), PlatformTypeEnum.PLATFORM_TYPE.QINIUYUN.getCode());
                logger.info("上传七云的路径：{}", url);
            } catch (Exception e) {
                logger.error(e.getMessage(), e);
            }
            logger.info("{}，{}，又拍云特写上传结束", ip, plateNumber);
        });
        this.executor.execute(() -> {
            String rsp;
            long beginTime = System.currentTimeMillis();
            CameraParam cameraParam = new CameraParam();
            cameraParam.setShootTime(new Date());
            cameraParam.setPlateColor(strColor);
            cameraParam.setCarNo(plateNumber);
            cameraParam.setCameraIp(ip);
            cameraParam.setPicPath(picPath.substring(1));
            logger.info("openGate [ip: {}, plateNumber: {}, plateColor: {}, picPath: {}, shootTime: {}]", new Object[]{ip, plateNumber, strColor, picPath, cameraParam.getShootTime()});
            CameraRecord record = new CameraRecord();
            record.setId(ObjectId.id());
            record.setShootTime(new Date());
            record.setPlateColor(strColor);
            record.setCarNo(plateNumber);
            record.setIp(ip);
            record.setPicPath(picPath);
            record.setCompleteStatus("0");
            this.cameraRecordDAO.add(record);
            long requestId = System.nanoTime();
            String postUrl = this.httpBaseUrl + "modules/ext/scheduling/dispatch?" + requestId;
            ParkingEquip equip = this.parkingEquipDAO.findByColumn(new PV[]{PV.nv("ip", ip)});
            String operateTxt = AisleDirectionEnum.ENTRY.getValue().equals(equip.getAisleDirection()) ? "入场动作" : "出场动作";
            if (AisleDirectionEnum.ENTRY.getValue().equals(equip.getAisleDirection())) {
                rsp = httpCircuitBreaker(postUrl, cameraParam);
            } else {
                rsp = (String) HttpClientUtil.okhttpPost(postUrl, cameraParam);
            }
            logger.info("操作：{}-----dispatch----http请求,车牌号：{},耗时：{}ms,返回结果：{}", new Object[]{operateTxt, cameraParam.getCarNo(), Long.valueOf(System.currentTimeMillis() - beginTime), rsp});
            if (StringUtils.isNotEmpty(rsp)) {
                this.billingResultService.handle(cameraParam, rsp);
                try {
                    this.billingResultService.handleEquipVersion(cameraParam, rsp);
                } catch (Exception e) {
                    logger.error("判断设备型号出错{}", e);
                }
            } else if (AisleDirectionEnum.ENTRY.getValue().equals(equip.getAisleDirection())) {
                String aisleId = equip.getAisleId();
                ParkingEquip ledEquip = this.parkingEquipDAO.findByColumn(new PV[]{PV.nv("aisle_id", aisleId), PV.nv("equip_type", 3)});
                if (ledEquip != null) {
                    String ledIp = ledEquip.getIp();
                    MonitorServer.sendToShowAndVoice(ledIp, new String[]{cameraParam.getCarNo(), "欢迎光临"}, "欢迎光临");
                }
                CameraServer.openGate(cameraParam.getCameraIp(), cameraParam.getCarNo());
                logger.info("入场动作-未获取云端返回结果-执行开闸。车牌号：{},开闸ip:{}", cameraParam.getCarNo(), cameraParam.getCameraIp());
                CompletableFuture.runAsync(() -> {
                    logger.info("云端无响应 放行采集保存 ！ ");
                    ReleaseRecord releaseRecord = new ReleaseRecord();
                    releaseRecord.setUrl(picPath.substring(1));
                    releaseRecord.setForbiddenReleaseType(ReleaseRecordForbidTypeEnum.OTHER.getValue());
                    releaseRecord.setPassType(ReleaseRecordPassTypeEnum.AUTO.getValue());
                    releaseRecord.setCrossType(ReleaseRecordCrossTypeEnum.TEMPCAR.getValue());
                    releaseRecord.setCarNo(cameraParam.getCarNo());
                    releaseRecord.setAccessibleId(equip.getAisleId());
                    releaseRecord.setRemark("出场动作-未获取云端返回结果-不执行开闸!");
                    releaseRecordSaveHandle(releaseRecord, cameraParam.getCameraIp(), null);
                });
            } else {
                logger.info("出场动作-未获取云端返回结果-不执行开闸，车牌号：{},开闸ip:{}", cameraParam.getCarNo(), cameraParam.getCameraIp());
                CompletableFuture.runAsync(() -> {
                    logger.info("云端无响应 不放行采集保存 ！ ");
                    ReleaseRecord releaseRecord = new ReleaseRecord();
                    CameraServer.fsTimeMap.remove(cameraParam.getCameraIp());
                    CameraServer.fsStrNumbers.remove(cameraParam.getCameraIp());
                    releaseRecord.setUrl(picPath.substring(1));
                    releaseRecord.setForbiddenReleaseType(ReleaseRecordForbidTypeEnum.OTHER.getValue());
                    releaseRecord.setPassType(ReleaseRecordPassTypeEnum.FORBBDEN.getValue());
                    releaseRecord.setCrossType(ReleaseRecordCrossTypeEnum.TEMPCAR.getValue());
                    releaseRecord.setCarNo(cameraParam.getCarNo());
                    releaseRecord.setAccessibleId(equip.getAisleId());
                    releaseRecord.setRemark("出场动作-未获取云端返回结果-不执行开闸!");
                    releaseRecordSaveHandle(releaseRecord, cameraParam.getCameraIp(), null);
                });
            }
            logger.info("操作：{},车牌号：{},摄像枪ip:{},总耗时：{}ms", new Object[]{operateTxt, cameraParam.getCarNo(), cameraParam.getCameraIp(), Long.valueOf(System.currentTimeMillis() - beginTime)});
        });
    }

    private String httpCircuitBreaker(String postUrl, CameraParam cameraParam) {
        String result;
        long beginTime = System.currentTimeMillis();
        FutureTask<String> task = new FutureTask<>(new 1CallableThread(this, postUrl, cameraParam));
        new Thread(task).start();
        try {
            result = task.get(this.cloudHttpCircuitBreakerTime, TimeUnit.MILLISECONDS);
        } catch (Exception e) {
            result = null;
        }
        long endTime = System.currentTimeMillis();
        logger.info("客户端请求云端处理结果----cameraIp:{},carNo:{},http请求耗时 :{}ms,返回值:{}", new Object[]{cameraParam.getCameraIp(), cameraParam.getCarNo(), Long.valueOf(endTime - beginTime), result});
        return result;
    }

    public void fsOpenGateAfterHandle(String ip) {
        try {
            ParkingEquip equip = this.parkingEquipDAO.findByColumn(new PV[]{PV.nv("ip", ip)});
            if (ParkingVariable.parkingIsFullStatus.containsKey(equip.getParkingId()) && ((Boolean) ParkingVariable.parkingIsFullStatus.get(equip.getParkingId())).booleanValue()) {
                List<ParkingEquip> list = this.parkingEquipDAO.queryByColumn(PV.of(new Object[]{"parking_id", equip.getParkingId(), "aisle_direction", "1", "equip_type", "6"}));
                for (ParkingEquip item : list) {
                    int iRet = NetSDKLib.NETSDK_INSTANCE.Net_ImageSnap(((Integer) CameraServer.ipMapNCamId.get(item.getIp())).intValue(), new NetSDKLib.T_DCImageSnap.ByReference());
                    if (iRet == 0) {
                        logger.info("强制识别调用成功，IP：{}", item.getIp());
                        ParkingVariable.parkingIsFullStatus.put(item.getParkingId(), false);
                    }
                }
            }
        } catch (Exception e) {
            logger.error("满车调用入口强制识别 Exception:", e);
        }
    }

    public JSONObject noPlateNoHandle(String picPathAll) {
        JSONObject object = new JSONObject();
        try {
            logger.info("开始调用第三方识别");
            LicensePlateResp licensePlateResp = this.thirdUtilService.licensePlate(".." + picPathAll);
            logger.info("---百度识别结果----", licensePlateResp);
            if (licensePlateResp.getWords_result() != null && null == licensePlateResp.getError_code()) {
                String strNumber = licensePlateResp.getWords_result().getNumber();
                String strColor = licensePlateResp.getWords_result().getColor();
                object.put("strNumber", strNumber);
                object.put("strColor", strColor);
                logger.info("第三方识别---车牌号{}, 车牌颜色{}", strNumber, strColor);
                return object;
            }
            logger.error("第三方识别---错误码{}, 错误信息{}", licensePlateResp.getError_code(), licensePlateResp.getError_msg());
            return null;
        } catch (Exception e) {
            logger.error("noPlateNoHandle Exception:", e);
            return null;
        }
    }

    public void loopDetectorStatusHandle(String ip, int status, int equipType) {
        this.executor.execute(() -> {
            ParkingEquip equip = this.parkingEquipDAO.findByColumn(new PV[]{PV.nv("ip", ip), PV.nv("equip_type", equipType + "")});
            String postUrl = this.httpBaseUrl + "/modules/ext/api-duty/loop_detector_status";
            Map<String, String> map = new HashMap<>(4);
            map.put("equipId", (String) equip.getId());
            map.put("status", status + "");
            map.put("triggerTime", System.currentTimeMillis() + "");
            try {
                String rsp = (String) HttpClientUtil.httpPost(postUrl, map);
                JSONObject data = JSONObject.parseObject(rsp);
                logger.info("地感数据 loopDetectorStatus response：", data);
            } catch (Exception e) {
                logger.error("上传地感数据错误：", e);
            }
        });
    }

    public void releaseRecordSaveHandle(ReleaseRecord releaseRecord, String cameraIp, String localPic) {
        try {
            if (StringUtils.isEmpty(releaseRecord.getUrl())) {
                if (StringUtils.isNotEmpty(localPic)) {
                    String yunUrl = releaseRecordSavePic(localPic);
                    releaseRecord.setUrl(yunUrl);
                } else {
                    ResultPack resultPack = CameraServer.catchPicture(cameraIp, false);
                    String localCatchPic = ObjectUtils.isEmpty(resultPack) ? "" : "1".equals(resultPack.get("code").toString()) ? resultPack.get("message").toString() : "";
                    String remotePic = (StringUtils.isNotEmpty(localCatchPic) && localCatchPic.contains("/")) ? localCatchPic.substring(1) : "";
                    logger.info(" 采集放行采集记录无本地图且无云端图 ！抓图url ：{} ", remotePic);
                    releaseRecord.setUrl(remotePic);
                }
            }
            if (StringUtils.isEmpty(releaseRecord.getAccessibleId()) && !StringUtils.isEmpty(cameraIp)) {
                ParkingEquip equip = this.parkingEquipDAO.findByColumn(new PV[]{PV.nv("ip", cameraIp)});
                releaseRecord.setAccessibleId(equip.getAisleId());
            }
            Date newData = new Date();
            releaseRecord.setCreateTime(newData);
            releaseRecord.setUpdateTime(newData);
            String postUrl = this.httpBaseUrl + "modules/ext/release/add-release-record";
            String result = (String) HttpClientUtil.httpPost(postUrl, releaseRecord);
            JSONObject rsJson = JSON.parseObject(result);
            if ("1".equals(rsJson.getString("code"))) {
                logger.info("保存通道采集记录成功！");
            } else {
                logger.info("保存通道采集记录失败 ：参数{}", releaseRecord.toString());
            }
        } catch (Exception e) {
            logger.error("保存通道采集记录失败 :", e);
        }
    }

    public boolean isMonthRentCar(String carNo) {
        if (carNo.contains("无车牌") || carNo.contains("无牌车")) {
            return false;
        }
        try {
            String postUrl = this.httpBaseUrl + "modules/ext/record/parking-car-log/query-month-record";
            String result = (String) HttpClientUtil.httpPost(postUrl, carNo);
            JSONObject rsJson = JSON.parseObject(result);
            if ("1".equals(rsJson.getString("code"))) {
                return true;
            }
            return false;
        } catch (Exception e) {
            logger.error("查询是否为月保车失败:", e);
            return false;
        }
    }

    private static String releaseRecordSavePic(String picPath) {
        try {
            CommonFileService commonFileService = (CommonFileService) ContextHolder.get().service(CommonFileService.class);
            String remotePathWithOutFileName = picPath.substring(0, picPath.lastIndexOf("/") + 1);
            String url = commonFileService.uploadFile(remotePathWithOutFileName.substring(1), new File(CameraUtil.CLASS_PATH + picPath), PlatformTypeEnum.PLATFORM_TYPE.QINIUYUN.getCode());
            logger.info("采集通道放行图片 上传七云的路径：{}", url);
            return url;
        } catch (Exception e) {
            logger.error(e.getMessage(), e);
            return "";
        }
    }
}
